@@ -1,10 +1,10 @@
 from __future__ import annotations
-from xml.etree.ElementTree import Element, tostring, fromstring
-from typing import Optional, List, Type
+from xml.etree.ElementTree import Element, SubElement, tostring, fromstring
+from typing import List, Union
 from XmlElement.element_tag_value import ElementTagValue
 
-class XmlElement:
-    def __init__(self, n: str, a: Optional[dict] = {}, s: Optional[List[XmlElement]] = [], t: Optional[str] = None):
+class XmlElement():
+    def __init__(self, n: str, a: dict = {}, s: List[XmlElement] = [], t: str = None):
         """Create a new XmlElement.
         Keyword arguments:
         n -- XML tag name
@@ -18,12 +18,31 @@ class XmlElement:
         self.__add_subelement_attribute__(s)
         self.text = t
     
+
     def __add_subelement_attribute__(self, subelements:List[XmlElement]) -> None:
         """Internal function to allow the shorthand . operator to access findall()"""
         for subelement in subelements:
             setattr(self, subelement.name, ElementTagValue(self, subelement.name))
 
 
+    def __getitem__(self, tag_name:str) -> List[XmlElement]:
+        return self.findall(tag_name)
+
+
+    # def __setitem__(self, tag_name:str, elements:List[XmlElement]):
+    #     for e in elements:
+    #         if e.name != tag_name:
+    #             raise KeyError(f'Not all tag names equals "{tag_name}" in new XmlElements list.')
+    #     self.__delitem__(tag_name)
+    #     self.extend(elements)
+
+    
+    # def __delitem__(self, tag_name:str):
+    #     for e in self.findall(tag_name):
+    #         self.subelements.remove(e)
+    #     super().__delattr__(tag_name)
+
+
     def set(self, key: str, value:str) -> None:
         """Create or update an attribute
         Keyword arguments:
@@ -31,7 +50,6 @@ class XmlElement:
         value -- XML attribute value
         """
         self.attributes = { **self.attributes, **{key: value} }
-        pass
 
 
     def append(self, subelement: XmlElement) -> None:
@@ -64,7 +82,7 @@ class XmlElement:
         return e
     
 
-    def to_string(self, encoding:Optional[str] = "unicode") -> str:
+    def to_string(self, encoding:str = "unicode") -> str:
         """Render this XmlElement to string
         Keyword arguments:
         encoding -- The output encoding (default: 'unicode')
@@ -72,7 +90,7 @@ class XmlElement:
         return tostring(self.to_etree_element(), encoding=encoding)
 
 
-    def find(self, name: Optional[str] = None) -> XmlElement:
+    def find(self, tag_name: str = None) -> Union[XmlElement, None]:
         """Return the first subelement with a given name or 
         None if no element with such a name exists
         Keyword arguments:
@@ -80,12 +98,12 @@ class XmlElement:
         """
         for s in self.subelements:
             if not s == None:
-                if name == None or s.name == name:
+                if tag_name == None or s.name == tag_name:
                     return s
         return None
 
 
-    def findall(self, name: Optional[str] = None) -> List[XmlElement]:
+    def findall(self, tag_name:str = None) -> List[XmlElement]:
         """Return all subelements with a given name or an empty 
         list if no element with such a name exists
         Keyword arguments:
@@ -94,13 +112,13 @@ class XmlElement:
         result = []
         for s in self.subelements:
             if not s == None:
-                if name == None or s.name == name:
+                if tag_name == None or s.name == tag_name:
                     result.append(s)
         return result
         
 
     @staticmethod
-    def from_etree_element(element: Type[Element]) -> XmlElement:
+    def from_etree_element(element: Element) -> XmlElement:
         """Recursively create a XmlElement from a given xml.etree.ElementTree.Element object
         Keyword arguments:
         element -- The xml.etree.ElementTree.Element to import
